*-- Before you integrate FRX2Any into your VFP application you should realize that FRX2Any
*-- requires GDIPlus.DLL which is freely available and can be installed on Win98 and higher.
*-- If you have not installed WinXP or .NET framework then you can download this DLL from
*-- http://www.microsoft.com/msdownload/platformsdk/sdkupdate/psdkredist.htm
*-- or
*-- http://www.dll-files.com/dllindex/dll-files.shtml?gdiplus


***************************************************************************************************************************
*-- OutPut options
***************************************************************************************************************************
#DEFINE cnOUTPUT_SCREEN			         		1
#DEFINE cnOUTPUT_PRINT			         		2
#DEFINE cnOUTPUT_EMAIL			         		3
#DEFINE cnOUTPUT_FILE		 	         		4

***************************************************************************************************************************
*-- IMAGE's output file formats
***************************************************************************************************************************
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_BMP          1
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_JPG			2
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_GIF			3
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_TIF			4
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_PNG			5

***************************************************************************************************************************
*-- Enumeration type for the various axis types that are available
***************************************************************************************************************************
#DEFINE cnCHART_AXIS_TYPE_LINERAL				0
#DEFINE cnCHART_AXIS_TYPE_LOG					1
#DEFINE cnCHART_AXIS_TYPE_DATE					2
#DEFINE cnCHART_AXIS_TYPE_TEXT					3
#DEFINE cnCHART_AXIS_TYPE_ORDINAL				4

***************************************************************************************************************************
*-- Enumeration type that defines the available types of Bar 
***************************************************************************************************************************
#DEFINE cnCHART_BARITEM_TYPE_CLUSTER			0																								
#DEFINE cnCHART_BARITEM_TYPE_OVERLAY			1																								
#DEFINE cnCHART_BARITEM_TYPE_SORTEDOVERLAY		2																										
#DEFINE cnCHART_BARITEM_TYPE_STACK				3																										
#DEFINE cnCHART_BARITEM_TYPE_PERCENTSTACK		4																										


LOCAL laX
LOCAL laY

LOCAL loFile
LOCAL loChartCurve

LOCAL lcOutPutFileName
LOCAL lcOutPutFilePath

CD LEFT(SYS(16,0), RAT('\', SYS(16,0)))

lcOutPutFileName = 'BarChartWithTextLabels'
lcOutPutFilePath = JUSTPATH(SYS(16,0)) + '\OutPut\'

SET PATH TO  ..\..\..\
SET CLASSLIB TO Chart IN FRX2Any.APP ALIAS Chart	

loFile = CREATEOBJ('Chart.ChartFile')

IF TYPE('loFile') = 'O'

	WITH loFile

*-- Unlock FRX2Any
		.UNLOCK('xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx')

*-- NOTE: loFile.cExportFileName should not include file extension. For example: loFile.cExportFileName = 'ReportOutput'
		.cExportFileName = lcOutPutFileName

*-- NOTE: loFile.cSaveFolder should contain only path to the output file. For example: loFile.cSaveFolder = 'c:\MyApp\MyOutPut\'
		.cSaveFolder     = lcOutPutFilePath

*-- Specifies that output file will be displayed after creation
		.nOutPutType     = cnOUTPUT_SCREEN

*-- Default value is cnIMAGE_OUTPUT_FILE_FORMAT_GIF
		.nImageFileType  = cnIMAGE_OUTPUT_FILE_FORMAT_PNG

*-- Specify Chart's properties
*-- For description of all Chart's properties and methods, please see FRX2Any help file.
		WITH .oPanel
*-- Set the main Title of the Chart
			.cTitle  = 'Cat stats'

			.nWidth  = 800
			.nHeight = 600

			WITH .oFontSpec
				.cFamily = 'Arial Black'
			ENDWITH

			WITH .oPanelFill
*-- Create a linear gradient color-fill
				.SetGradientFill(RGB(255,255,255), RGB(208,224,244), 2)
			ENDWITH

			WITH .oAxisFill
*-- Create a linear gradient color-fill
				.SetGradientFill(RGB(255,255,255), RGB(249, 253, 200), 2)
			ENDWITH

			WITH .oXAxis

				DIMENSION laX[6]

				laX[1] = 'Panther'
				laX[2] = 'Lion'
				laX[3] = 'Lynx'
				laX[4] = 'Cougar'
				laX[5] = 'Tiger'
				laX[6] = 'Leopard'

*-- Will use an ordinal axis with user-defined text labels.
				.nType = cnCHART_AXIS_TYPE_TEXT

*-- Set the XAxis labels
				.SetTextLabels(@laX)

*-- Draw the X tics between the labels instead of at the labels
				.lTicsBetweenLabels = .T.

*-- Set Title for X axis
				.cTitle = 'Big cats'

			ENDWITH

			WITH .oYAxis
*-- Set Title for Y axis
				.cTitle    = 'Population'
				.nScaleMax = 100
				.lShowGrid = .T.				
			ENDWITH

			.nBarType = cnCHART_BARITEM_TYPE_PERCENTSTACK

*-- In this case we don't need to provide laX array of numebic precision X values.
			DIMENSION laX[1]

*-- Make up some random data points
			DIMENSION laY[6]
			
			laY[1] = 100
			laY[2] = 115
			laY[3] = 75
			laY[4] = 22
			laY[5] = 98
			laY[6] = 40

*-- Generate a red bar with 'Here' in the legend
			loChartCurve = .AddBar('Here', @laX, @laY, RGB(255, 0 , 0))

*-- Make up some random data points
			DIMENSION laY[6]
			
			laY[1] = 90
			laY[2] = 100
			laY[3] = 95
			laY[4] = 35
			laY[5] = 80
			laY[6] = 35

*-- Generate a green bar with 'There' in the legend
			loChartCurve = .AddBar('There', @laX, @laY, RGB(0, 128, 0))

*-- Make up some random data points
			DIMENSION laY[6]
			
			laY[1] = 80
			laY[2] = 110
			laY[3] = 65
			laY[4] = 15
			laY[5] = 54
			laY[6] = 67

*-- Generate a blue bar with 'Elsewhere' in the legend
			loChartCurve = .AddBar('Elsewhere', @laX, @laY, RGB(0, 0, 255))

		ENDWITH

		.SAVE()

		.RELEASE()

	ENDWITH

ENDIF

